libsemigroups: Library for semigroups and monoids
=================================================

Description
-----------

C++ library for semigroups and monoids; used in GAP's package
Semigroups.

License
-------

GPL-3.0


Upstream Contact
----------------

http://james-d-mitchell.github.io/libsemigroups
https://github.com/james-d-mitchell/libsemigroups
